HitsAtK
=======

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: HitsAtK
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~HitsAtK.increasing
      ~HitsAtK.key
      ~HitsAtK.name
      ~HitsAtK.synonyms
      ~HitsAtK.value_range

   .. rubric:: Methods Summary

   .. autosummary::

      ~HitsAtK.__call__
      ~HitsAtK.expected_value
      ~HitsAtK.variance

   .. rubric:: Attributes Documentation

   .. autoattribute:: increasing
   .. autoattribute:: key
   .. autoattribute:: name
   .. autoattribute:: synonyms
   .. autoattribute:: value_range

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: expected_value
   .. automethod:: variance
